@@ -1,17 +1,18 @@
 import warnings
+from collections import namedtuple
 from datetime import datetime
 from typing import Dict, Tuple, NamedTuple, Optional
 
 from aiohttp import ClientSession, ClientResponse
 from async_timeout import timeout
 
-from ..config import get_client_id, get_oauth
+from ..config import get_client_id, get_oauth, DEFAULT_CLIENT_ID
 from ..data import UserFollowers, UserInfo, RateLimit
 
 __all__ = ('CHANNEL_CHATTERS_URL', 'get_channel_chatters', 'get_stream_data', 'get_url', 'get_user_data', 'get_user_id',
            'STREAM_API_URL', 'USER_API_URL', 'get_user_followers', 'USER_FOLLOWERS_API_URL', 'get_headers',
            'get_user_info', 'get_user_creation_date', 'USER_ACCOUNT_AGE_API', 'CHANNEL_INFO_API', 'get_channel_info', 'ChannelInfo',
-           'get_channel_name_from_user_id')
+           'get_channel_name_from_user_id', 'OauthTokenInfo', 'get_oauth_token_info', '_check_token')
 
 USER_API_URL = 'https://api.twitch.tv/helix/users?login={}'
 STREAM_API_URL = 'https://api.twitch.tv/helix/streams?user_login={}'
@@ -178,3 +179,45 @@ async def get_channel_name_from_user_id(user_id: str, headers: dict = None) -> s
 
     _channel_id_to_name_cache[user_id] = channel_info.broadcaster_name
     return channel_info.broadcaster_name
+
+
+OauthTokenInfo = namedtuple('OauthTokenInfo', 'client_id login scopes user_id expires_in error_message status')
+
+
+async def get_oauth_token_info(token: str) -> OauthTokenInfo:
+    token = token.replace('oauth:', '')
+    _, json = await get_url('https://id.twitch.tv/oauth2/validate', headers={'Authorization': f'OAuth {token}'})
+    return OauthTokenInfo(client_id=json.get('client_id', ''),
+                          login=json.get('login', ''),
+                          scopes=json.get('scopes', []),
+                          user_id=json.get('user_id', ''),
+                          expires_in=json.get('expires_in', 0),
+                          error_message=json.get('message', ''),
+                          status=json.get('status', -1))
+
+
+def _print_quit(msg):
+    print(msg)
+    input('\npress ENTER to exit...')
+    exit(1)
+
+
+def _check_token(info: OauthTokenInfo):
+    if not info.login:
+        _print_quit(f'\nfailed to login to chat, irc oauth token is INVALID ("oauth" in the config)\n'
+                    f'twitch returned status code ({info.status}) and error message ({info.error_message})')
+
+    if info.expires_in <= 0:
+        _print_quit(f'\nfailed to login to chat, irc oauth token is EXPIRED ("oauth" in the config)\n'
+                    f'twitch returned status code ({info.status}) and error message ({info.error_message})')
+
+    if get_client_id() != DEFAULT_CLIENT_ID and info.client_id != get_client_id():
+        print(f'\n{"=" * 50}\nthe client id for the irc oauth token ("oauth" in the config) DOES NOT match the client id in the config\n'
+              f'TWITCH API CALLS WILL NOT WORK until the irc token is regenerated using the client id in the config\n'
+              f'\nreplace the <CLIENT_ID_HERE> and <REDIRECT_HERE> in the following auth URL to match your twitch dev app info\nthen visit the URL with '
+              f'a browser signed into the bots account to correct this problem\nmake sure to replace the current irc oauth token with the new one ("oauth" in config)'
+              f'\n\nhttps://id.twitch.tv/oauth2/authorize?response_type=token&client_id=<CLIENT_ID_HERE>&redirect_uri=<REDIRECT_HERE>'
+              f'&scope=chat:read+chat:edit+channel:moderate+whispers:read+whispers:edit+channel_editor'
+              f'\n{"=" * 50}\n')
+
+    print(f'logged into chat as "{info.login}"')
